@@ -146,10 +146,12 @@ class ViewQtApp(QtWidgets.QApplication):
 
             delta = range_.max - range_.min
 
+            result.setDecimals(6)
             result.setMinimum(range_.min +
                               1e-2*delta*(not range_.inclusive[0]))
             result.setMaximum(range_.max -
                               1e-2*delta*(not range_.inclusive[1]))
+            result.setStepType(QtWidgets.QAbstractSpinBox.AdaptiveDecimalStepType)
             result.setSingleStep(5e-2*delta)
             result.setValue(val)
             result.valueChanged[float].connect(callback)
@@ -265,8 +267,11 @@ class ViewQtApp(QtWidgets.QApplication):
         self.mdi_area = QtWidgets.QMdiArea(self.main_window)
         self.config_dock = QtWidgets.QDockWidget('Options', self.main_window)
         self.config_dock.setObjectName('config_dock')
-        self.config_widget = QtWidgets.QFrame(self.config_dock)
-        self.config_dock.setWidget(self.config_widget)
+        self.scroll_widget = QtWidgets.QScrollArea(self.config_dock)
+        self.config_widget = QtWidgets.QFrame(self.scroll_widget)
+        self.scroll_widget.setWidget(self.config_widget)
+        self.scroll_widget.setWidgetResizable(True)
+        self.config_dock.setWidget(self.scroll_widget)
 
         self.main_window.setCentralWidget(self.mdi_area)
         self.main_window.addDockWidget(QtCore.Qt.LeftDockWidgetArea, self.config_dock)
@@ -397,6 +402,11 @@ class ViewQtApp(QtWidgets.QApplication):
             pass
         self._last_scope['visual_objects'] = self._visual_cache
 
+        linked_visuals = [self._visual_cache[v] for v in
+                          self._last_scope.get('visual_link_rotation', [])]
+        for visual in linked_visuals:
+            visual.enable('link_rotation', targets=linked_visuals)
+
         if self._currently_refreshing:
             self._currently_refreshing = False
             self.main_window._load_state()
