@@ -4,11 +4,13 @@ from .version import __version__
 
 Center = try_to_import('.Center', 'Center', __name__)
 Colormap = try_to_import('.Colormap', 'Colormap', __name__)
+Diffraction = try_to_import('.Diffraction', 'Diffraction', __name__)
 Garnett = try_to_import('.Garnett', 'Garnett', __name__)
 GTAR = try_to_import('.GTAR', 'GTAR', __name__)
 Plato = try_to_import('.Plato', 'Plato', __name__)
 Pyriodic = try_to_import('.Pyriodic', 'Pyriodic', __name__)
 Save = try_to_import('.Save', 'Save', __name__)
+SaveGarnett = try_to_import('.SaveGarnett', 'SaveGarnett', __name__)
 Selection = try_to_import('.Selection', 'Selection', __name__)
 ViewNotebook = try_to_import('.ViewNotebook', 'ViewNotebook', __name__)
 ViewQt = try_to_import('.ViewQt', 'ViewQt', __name__)
